@@ -1,5 +1,5 @@
-// -*- indent-tabs-mode: nil; tab-width: 4; show-trailing-whitespace: t; c-indent-level: 4; c-basic-offset: 4; -*-
-// Copyright (C) 2010 - 2011  Dirk Eddelbuettel and Romain Francois
+
+// Copyright (C) 2010 - 2022  Dirk Eddelbuettel and Romain Francois
 //
 // This file is part of RProtoBuf.
 //
@@ -359,7 +359,7 @@ void CHECK_messages(const GPB::FieldDescriptor* field_desc, SEXP values) {
         Rcpp::stop("expecting a list of messages");
     }
 
-    const char* target = field_desc->message_type()->full_name().c_str();
+    std::string_view target = field_desc->message_type()->full_name();
     int n = LENGTH(values);
     for (int i = 0; i < n; i++) {
         if (!isMessage(VECTOR_ELT(values, i), target)) {
@@ -371,8 +371,9 @@ void CHECK_messages(const GPB::FieldDescriptor* field_desc, SEXP values) {
             out << i;
             s = out.str();
             // }}}
-            string message = "List element " + s + " is not a message " +
-                             "of the appropriate type ('" + target + "')";
+            std::string message = "List element " + s + " is not a message " +
+                                  "of the appropriate type ('" +
+                                  std::string(target) + "')";
             Rcpp::stop(message.c_str());
         }
     }
@@ -397,10 +398,13 @@ void CHECK_repeated_vals(const GPB::FieldDescriptor* field_desc, SEXP value, int
                 }
                 case S4SXP: {
                     /* check that this is a message of the appropriate type */
-                    if (!isMessage(value, field_desc->message_type()->full_name().c_str())) {
-                        string message = "Not a message of type '" +
-                                         field_desc->message_type()->full_name() + "'";
-                        Rcpp::stop(message.c_str());
+                    if (!isMessage(value,
+                                   field_desc->message_type()->full_name())) {
+                      std::string message =
+                          "Not a message of type '" +
+                          std::string(field_desc->message_type()->full_name()) +
+                          "'";
+                      Rcpp::stop(message.c_str());
                     }
                     break;
                 }
@@ -543,7 +547,7 @@ void setNonRepeatedMessageField(GPB::Message* message, const Reflection* ref,
         }
         case CPPTYPE_INT32: {
             if (TYPEOF(value) == STRSXP) {
-                const string int32str = COPYSTRING(CHAR(STRING_ELT(value, 0)));
+                const std::string int32str = COPYSTRING(CHAR(STRING_ELT(value, 0)));
                 ref->SetInt32(message, field_desc, Int32FromString<GPB::int32>(int32str));
                 break;
             } else {
@@ -553,7 +557,7 @@ void setNonRepeatedMessageField(GPB::Message* message, const Reflection* ref,
         }
         case CPPTYPE_UINT32: {
             if (TYPEOF(value) == STRSXP) {
-                const string uint32str = COPYSTRING(CHAR(STRING_ELT(value, 0)));
+                const std::string uint32str = COPYSTRING(CHAR(STRING_ELT(value, 0)));
                 ref->SetUInt32(message, field_desc, Int32FromString<GPB::uint32>(uint32str));
                 break;
             } else {
@@ -569,7 +573,7 @@ void setNonRepeatedMessageField(GPB::Message* message, const Reflection* ref,
             // TODO(mstokely) Rcpp::as<int64> of a STRSEXP should just
             // work for strings representing int64s.
             if (TYPEOF(value) == STRSXP) {
-                const string int64str = COPYSTRING(CHAR(STRING_ELT(value, 0)));
+                const std::string int64str = COPYSTRING(CHAR(STRING_ELT(value, 0)));
                 ref->SetInt64(message, field_desc, Int64FromString<GPB::int64>(int64str));
                 break;
             } else {
@@ -581,7 +585,7 @@ void setNonRepeatedMessageField(GPB::Message* message, const Reflection* ref,
             // TODO(mstokely) Rcpp::as<int64> of a STRSEXP should just
             // work for strings representing int64s.
             if (TYPEOF(value) == STRSXP) {
-                const string int64str = COPYSTRING(CHAR(STRING_ELT(value, 0)));
+                const std::string int64str = COPYSTRING(CHAR(STRING_ELT(value, 0)));
                 ref->SetUInt64(message, field_desc, Int64FromString<GPB::uint64>(int64str));
                 break;
             } else {
@@ -627,9 +631,9 @@ void setNonRepeatedMessageField(GPB::Message* message, const Reflection* ref,
             if (TYPEOF(value) == S4SXP && Rf_inherits(value, "Message")) {
                 GPB::Message* mess =
                     (GPB::Message*)EXTPTR_PTR(GET_SLOT(value, Rf_install("pointer")));
-                const char* type = mess->GetDescriptor()->full_name().c_str();
-                const char* target = field_desc->message_type()->full_name().c_str();
-                if (strcmp(type, target)) {
+                std::string_view type = mess->GetDescriptor()->full_name();
+                std::string_view target = field_desc->message_type()->full_name();
+                if (type != target) {
                     Rcpp::stop("wrong message type");
                 }
                 GPB::Message* m = ref->MutableMessage(message, field_desc);
